Class: Bible270::Like

Inherits:
ApplicationRecord show all
Defined in:
app/models/bible270/like.rb

Overview

A reader's heart on a reflection. There is nothing to a like but who gave it and when — the count is the number of rows, and the hover text is the name.